# CommScores Results

- Full Table
- Metabolites
- Heatmap
- Score Information

Blank cells signify scores that failed to simulate in the given conditions. The biomass yields are expressed in [gm/hr*(gm CDW)]

{{ table|safe }}

The MRO metabolites entries are the metabolites that are under competition in the simulated system. The MIP model1 metabolites and MIP model2 metabolites entries are the metabolites that are donated by Model1 or Model2 and consumed by Model2 or Model1, respectively. The CIP metabolites entries are the combined set of metabolites that the models excrete during their maximal growths.

{{ mets_table|safe }}

c_MIP1 and c_MIP2 represent the costless MIP sub-score for Model1 and Model2, respectively.

{{ heatmap|safe }}

### Novel scores

#### Functional Complementarity (FC)

The FC score is calculated as the Jiccard Index of ontologies O from either RAST or another annotation software available on KBase

\[ FC= \left( \frac{O_1 \cap O_2}{O_1 \cup O_2} \right)~~. \]
This score captures the potential for niche overlap and therefore negative interactions. The broad assessment of the entire genome further captures secondary metabolic interactions as well as the primary metabolism that is embodied in genome-scale metabolic models.

#### Growth Yield Difference (GYD)

The GYD score evaluates the disparity in growth rate between the isolated members

\[ GYD = \frac{abs(G_{1}-G_{2})}{min(G_{1}, G_{2})}~~, \]
by normalizing the difference in the member's growth rates by the growth rate of the slower growing member. A relatively large disparity in the isolate growth rates may foreshadow a negative interaction when the members are combined, where one member rapidly begins dominating the environment and media consumption which leaves the other member potentially starved and possibly launching antibiotic warfare in desparation to survive.

#### Costless Interaction Potential (CIP)

The CIP score quantifies the union of costless excreta CE (compounds that are excreted at maximal growth and therefore have no fitness cost associated with their excretion) in the isolated members

\[ CIP = len(CE_1 \cup CE_2)~~, \]
which may contextualize syntrophic exchanges in their likelihood for exchange based on the fitness expense of their excretion. Our curation of the MIP score can be further contextualized with costless excreta via the intersection of exchanged compounds in the MIP score and the CIP for the same member pair.

#### Biological Interaction Potential (BIT)

The BIT score categorizes the member interaction into one of the classical descriptions -- competitive, amensalism, neutral, parasitism, commensalism, and mutualism -- based on relative growth of the members as isolates G1 versus in the community environment G1,comm

\[ BIT_1 = G_{1,comm}-G_1 \]
\[ BIT_2 = G_{2,comm}-G_2 \]
which provides a tangible biological description of the member interaction based on growth through the primary metabolism.

### Curated scores

#### MRO

The Metabolic Resource Overlap (MRO) score is in the SMETANA suite and was published in several earlier studies as well, albeit with slight algorithmic variations. The MRO quantifies the fraction of a member's nutritional requirements, in a given media or the complete media by default, that overlap with the other member's nutritional requirements

\[ MRO= \frac{|M_1 \cap M_2|}{|M_1|} \]
and is importantly directional (by replacing the denominator member), which can capture directional dependencies of interactions (e.g. lawn versus spot). The minimal media M of each member is determined by minimizing the total exchange flux.

#### MIP

The Metabolic Interaction Potential (MIP) score is also in the SMETANA suite and earlier studies. This score quantifies syntrophic exchanges between the members. Our curation computes the MIP as the difference in exchanged compounds versus transported compounds in the compartmentalized community model

\[ MIP=M_{transports}-M_{exchanges}~~, \]
where compounds that the members are transporting but the community is not exchanging with the media must be sourced from syntrophy. The MIP compounds that are costlessly excreted can also be quantified as a subscore of the MIP, and may better represent the compounds that are favorably exchanged in the community.

#### PC

The Potential Cooperation (PC) score quantifies the net effect of co-growth relative to isolate growth, and in our curation is determined as the ratio of community growth to the sum of isolated member growths

\[ PC = \frac{G_{comm}}{G_1+G_2}~~, \]
and is therefore essentially a continuous quantitative representation of the discrete qualitative BIT score.

#### BSS

The Biosynthetic Support Score (BSS) score quantifies the capacity of a member to parasitize another member by topologically evaluating the proportion of a member's nutritional requirements that are in the other member's cytoplasmic metabolites

\[ BSS = \frac{M_i \cap R_j}{M_i}~~. \]
This score therefore quantifies the capacity or incentive for negative interaction.